(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof define === 'function' && define.amd ? define('chitu', ['exports'], factory) :
    (factory((global.chitu = global.chitu || {})));
}(this, (function (exports) { 'use strict';

/**
 * Module for checking variable types.
 *
 * @module type
 */
var type = {};
var types = 'Array Object String Date RegExp Function Boolean Number Error Null Undefined Symbol'.split(' ');
/**
 * Check the type of a value.
 *
 * @param  {String}  type  The primitive type as a capitalized string.
 * @param  {Mixed}   val   The value to check.
 *
 * @return {Boolean}
 */
type.is = function (type, val) {
  return Object.prototype.toString.call(val).slice(8, -1) === type;
};

// Populate helper methods.
types.forEach(function (t) {
  return type['is' + t] = function (v) {
    return type.is(t, v);
  };
});

/**
 * Return the value or execute as a function
 *
 * @module  value
 *
 * @param   {Mixed}  val     A value or a function that returns a value
 * @param   {Mixed}  [args]  One or more arguments
 *
 * @return  {Mixed}
 */
function value(val) {
  for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }

  return type.isFunction(val) ? val.apply(this, args) : val;
}

/**
 * Round a number to a given number of decimal places.
 *
 * @param   {Number}  val         The number to round
 * @param   {Number}  [places=2]  The number of places to round to
 *
 * @return  {Number}
 */
function round(val) {
  var places = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 2;

  return Number(val.toFixed(places));
}

function ordinal(num) {
    var suffix = ['th', 'st', 'nd', 'rd'];
    var v = num % 100;

    return num + (suffix[(v - 20) % 10] || suffix[v] || suffix[0]);
}

exports.type = type;
exports.value = value;
exports.round = round;
exports.ordinal = ordinal;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=chitu.js.map
